DropdownButtonStyle class

Constructors

const

Properties

backgroundColor Color?
final
border Border?
final
boxShadow List<BoxShadow>?
final
constraints BoxConstraints?
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
mainAxisAlignment MainAxisAlignment?
final
padding EdgeInsets?
final
primaryColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape ShapeBorder?
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited